@@ -19,10 +19,13 @@
 #'   with fully missing genotype. Ignored if CallRate is a named vector. NOTE:
 #'   default changed from 0.4 (up to version 2.8.5) to 0 (from version 2.9).
 #' @param MAF  either a single number with minimum minor allele frequency, and
-#'   allele frequencies will be sampled uniformly between this minimum and 0.5,
-#'   OR a vector with minor allele frequency at each locus. In both cases, this
-#'   is the MAF among pedigree founders, the MAF in the sample will deviate due
-#'   to drift.
+#'   allele frequencies will be sampled uniformly between this minimum
+#'   ('min_maf') and 1-min_maf (NOTE: between min_maf and 0.5 up to version
+#'   2.11) OR a vector with minor allele frequency at each locus. In both cases,
+#'   this is the MAF among pedigree founders; the MAF in the sample will deviate
+#'   due to drift. Occasionally, alleles may get fixed, and all founders
+#'   carrying the allele simulated as non-genotyped, resulting in a sample MAF
+#'   of 0.
 #' @param CallRate either a single number for the mean call rate (genotyping
 #'   success), OR a vector with the call rate at each SNP, OR a named vector
 #'   with the call rate for each individual. In the third case, ParMis is
@@ -140,6 +143,10 @@
 #' rownames(Geno_dups) <- Dups_grif$ID2
 #' Geno_sim <- rbind(Geno_sim, Geno_dups)
 #'
+#' \dontrun{
+#' # write simulated genotypes to a file, e.g. for use by PLINK:
+#' GenoConvert(Geno_A, InFormat='seq', OutFormat='ped', OutFile = sim_genotypes)
+#' }
 #'
 #' @importFrom stats rbinom runif rbeta
 #'
@@ -201,7 +208,7 @@ SimGeno <- function(Pedigree,
   #================================
   # minor allele frequencies (among founders)
   if (length(MAF)==1) {
-    Q <- round(runif(nSnp, min=MAF, max=0.5),3)
+    Q <- round(runif(nSnp, min=MAF, max=1-MAF),3)
   } else {
     Q <- as.numeric(MAF)
   }
@@ -481,10 +488,10 @@ SelectNotSampled <- function(Ped, ParMis) {
     for (p in 1:2) {
       if (ParMis[p]>0) {
         IsParent <- which(Ped[,1] %in% Ped[,p+1])
-      }
-      if (round(length(IsParent)*ParMis[p]) > 0) {
-        NotSampled <- c(NotSampled,
-                        sample(IsParent, round(length(IsParent)*ParMis[p]), replace=FALSE))
+        if (round(length(IsParent)*ParMis[p]) > 0) {
+          NotSampled <- c(NotSampled,
+                          sample(IsParent, round(length(IsParent)*ParMis[p]), replace=FALSE))
+        }
       }
     }
   }
